@@ -33,7 +33,7 @@
 // that zoom has a related internal dimension
 // ie a reference to the current cell
 
-
+int liqcell_showdebugboxes=0;
 
 
 
@@ -552,13 +552,9 @@ __tz_one("showndone");
 	
 	// 20090526_230043 lcuk : todo: test whether bailing if painting "dealt with" harms anything
 	// 20090526_230103 lcuk : i dont think it does right now
-
+	
 __tz_one("paintdone");
 
-	liqcell_kineticboiloff(self);
-
-__tz_one("kindone");
-
 
 
 	char *t=NULL;
@@ -606,7 +602,7 @@ __tz_one("backdone");
 			if(!easypaint_isloading_image)
 			{
 				//easypaint_isloading_image=liqimage_newfromfile("media/sun.png",0,0,0);
-				easypaint_isloading_image=liqimage_newfromfile("media/pleasewait.png",0,0,0);
+				easypaint_isloading_image=liqimage_newfromfile("/usr/share/liqbase/media/pleasewait.png",0,0,0);
 			}
 			if(easypaint_isloading_image)
 			{
@@ -969,10 +965,53 @@ __tz_one("overlaydone");
 
 __tz_one("borderdone");
 
+	{
+			liqcell *p = liqcell_getlinkparent(self);
+			if(p)
+			{
+				if(p->w < self->w)
+				{
+					// show a position indicator bar..
+					
+					
+				}
+				if(p->h < self->h)
+				{
+					// show a position indicator bar..
+					
+					float sx = self->x;
+					float sy = self->y;
+					float ww = w;
+					float sw = self->w;
+					float pw = p->w;
+					float hh = h;
+					float sh = self->h;
+					float ph = p->h;		
+					// ph = 480
+					// sh = 2000
+					// sy = -200
+					// get the relative size of the knob as a fraction of total height             == (0.25)
+					float f  = ph    / sh;
+					// get the relative offset of the knob as a fraction of total height           == (0.10)
+					float fy = (-sy) / sh;
+					// transform the knob size (0.25) into the context of the parent height (480/2000)  == (0.06)
+					float f2 = f * (ph / sh);						
+					// transform the knob offset (0.1) into the context of the parent height 0.1 + (480/2000) == (0.124) and starting from the parent offset
+					float fy2 = fy + (fy * (ph / sh));					
+					liqcliprect_drawboxwashcolor(cr,x+w-4,y+(fy2*hh) ,12,(f2*hh),0,255);
+					
+				}
+			}
+	}
+
+ 
+__tz_one("scrolldone");
+
+
 	if(liqcell_getenabled(self)==0)
 	{	
 
-		liqcliprect_drawboxfadeoutcolor(cr,x,y,w,h,128,128,128,  128);
+		liqcliprect_drawboxfadeoutcolor(cr,x,y,w,h, 100,128,128,  180);
 	}
 
 
@@ -998,9 +1037,12 @@ __tz_one("disablerdone");
 // 20090422_010005 lcuk : ive switched these on often enough to want a proper flag
 // 20090422_010018 lcuk : it cannot be long before i need proper param saving like original liqbase
 // 20090422_010032 lcuk : however i must iron out how outside applications will handle preferences like this
-/*
-	if(1)
+
+	if(liqcell_showdebugboxes)
 	{
+
+		liqapp_log("#################################### liqcell easypaint (%i,%i) :: %s   xy(%i,%i)-wh(%i,%i)  ",self->w,self->h,self->name,x,y,w,h);
+
 		//t = liqcell_propgets(self,"bordercolor",NULL);
 		t = "rgb(100,100,100)";
 		if(t)
@@ -1030,13 +1072,21 @@ __tz_one("disablerdone");
 
 					int ww=liqfont_textwidth (infofont,info);
 					int hh=liqfont_textheight(infofont);
+					int ys=y+(h-hh)/2;
 
-					liqcliprect_drawtextinside_color( cr, infofont,  x,y+(h-hh)/2, ww,hh, info,0, 255,128,128);
+					liqcliprect_drawtextinside_color( cr, infofont,  x,ys,    ww,hh, info,0, 255,128,128);
+					
+					
+					if(liqcell_getclassname(self))
+					{
+				
+						liqcliprect_drawtextinside_color( cr, infofont,  x,ys+hh, ww,hh, liqcell_getclassname(self)  ,0, 255,68,128);
+					}
 				}
 			}
 		}
 	}
- */
+ 
 
 
 	//liqcliprect_drawboxfillcolor(cr,x,y,2,h,((tz[tzused-1]-tz[0]) % 16) * 16,((tz[tzused-1]-tz[0]) % 32) * 8,((tz[tzused-1]-tz[0]) % 64) * 4);
@@ -1051,6 +1101,54 @@ __tz_one("disablerdone");
 __tz_one("reldone");
 
 
+// 20090614_185314 lcuk : moved kinetic till AFTER i am finished, seems reasonable enough :)
+
+
+
+// 20090613_031908 lcuk : kinetic scaling hack test.  result: not too convincing in practice.  removed, leaving code for academic interest
+/*	
+	if( self->kineticy && self->linkparent->h)
+	{
+		float fy = ((float)self->kineticy) / ((float)self->linkparent->h);
+		if(fy<0)fy=-fy;
+		fy*=2;
+		int nh = ((float)h) * (1-fy);
+		//if(nh>h)nh=h;
+		
+		liqapp_log("kin h=%3i ky=%3i fy=%3.3f  nh=%3i",self->linkparent->h,self->kineticy,fy,nh);
+		
+		y += (h-nh)/2;
+		h=nh;
+		if(h<1)
+		{
+			liqcliprect_release(cr);
+			return;
+		}
+		
+		x+=(w-(w*(1-fy)))/2;
+		w=(w*(1-fy));
+		
+	}
+ 
+__tz_one("kinzoomdone");
+
+*/	
+
+
+	// 20090614_184351 lcuk : mmm in the kinetic boiloff, i adjust the position of the cell.
+	// technically, this should also effect the current position I am attempting to render for..
+
+	liqcell_kineticboiloff(self);
+
+
+
+
+
+
+__tz_one("kindone");
+
+
+
 
 
 // whole logging block put in place because of a serious performance bottleneck in some test code
